# CLI / Configuration tools

This folder contains scripts made for configuring Sardine in an easy/friendly way.

* `sardine-config`: `argparse` based tool to deal with the `config.json` file.
* `sardine-config-python`: opening `$EDITOR` to configure code that will be evaluated when the library is imported.
* `sardine-config-superdirt': opening `$EDITOR` to configure code that will be evaluated if Sardine is booted internally.
